imodels.rule_list.bayesian_rule_list API documentation
Description: [bayesian rule list](https://arxiv.org/abs/1602.08610) (based on [this implementation](https://github.com/tmadl/sklearn-expertsys)) - learn a compact …

# Module `imodels.rule_list.bayesian_rule_list`

bayesian rule list (based on this implementation) - learn a compact rule list

Expand source code

    '''[bayesian rule list](https://arxiv.org/abs/1602.08610) (based on [this implementation](https://github.com/tmadl/sklearn-expertsys)) - learn a compact rule list
    '''

## Sub-modules

`imodels.rule_list.bayesian_rule_list.bayesian_rule_list`
`imodels.rule_list.bayesian_rule_list.brl_util`